# VERY MUCH WORK IN PROGRESS

## Dependencies
+ MOPAC in $PATH (some search is done for slightly different names, but older versions might not parse)
+ rdkit

## Usage

coming soon tm

## Tests

done for Ubuntu 24 LTS and Fedora 40,

Python 3.9-12
